@@ -6,8 +6,8 @@ __all__ = [
     'current_task_or_thread',
     'merge_aiters',
     'to_thread',
-    'ToLoop',
     'MultiprocessingLogging',
+    'match_any',
     'peek_stderr',
     'peek_stdout',
     'peek_textio',
@@ -18,18 +18,16 @@ __all__ = [
     'Running',
     'run_in_process',
     'ExcThread',
-    'ThreadSafeAsyncioEvent',
     'ThreadTaskIdComposer',
 ]
 
 from .done_callback import TaskDoneCallback, ThreadDoneCallback, ThreadTaskDoneCallback
 from .func import agen_with_wait, current_task_or_thread, merge_aiters, to_thread
-from .loop import ToLoop
 from .multiprocessing_logging import MultiprocessingLogging
+from .path import match_any
 from .peek import peek_stderr, peek_stdout, peek_textio
 from .profile import profile_func
 from .pubsub import PubSub, PubSubItem
 from .run import ExecutorFactory, Running, run_in_process
 from .thread_exception import ExcThread
-from .thread_safe_event import ThreadSafeAsyncioEvent
 from .thread_task_id import ThreadTaskIdComposer
